library(dplyr)
library(ggplot2)
library(viridis)
library(ggnewscale)

setwd(".")

s1=read.csv("data_s1_Sayol.csv")
s7=read.csv("data_s7_Sayol.csv")
s3=read.csv("data_s3_Sayol.csv")

plot_ex = function(Archipelago, remove_incom = FALSE) {
  miss_sp=s3[rowSums(is.na(s3[, 4:11]))==0, "species"]
  
  if (remove_incom) {
    NZ = s1 %>%
      subset(s1[,Archipelago] != "NotPresent" & !species %in% miss_sp) %>%
      select(species, Archipelago)
  } else {
    NZ = s1 %>%
      subset(s1[, Archipelago] != "NotPresent") %>%
      select(species, Archipelago)
  }
  
  
  colnames(NZ)[2] = "Archipelago"
  
  Hw = s7 %>% right_join(NZ, by = "species")
  
  traits_log = cbind(log10(Hw[, 5:13]), Hw[, 14])
  traits_cs = as.data.frame(apply(traits_log, 2, scale))
  pca = prcomp(traits_cs, center = FALSE, scale = FALSE)
  pc = cbind(Hw$species, Hw[, "Archipelago"], as.data.frame(pca$x[, 1:3]))
  colnames(pc)[1] = "species"
  colnames(pc)[2] = "NZ"
  
  get_density <- function(x, y, ...) {
    dens <- MASS::kde2d(x, y, ...)
    ix <- findInterval(x, dens$x)
    iy <- findInterval(y, dens$y)
    ii <- cbind(ix, iy)
    return(dens$z[ii])
  }
  
  pc$density_PC1_PC2 <- get_density(pc$PC1, pc$PC2, n = 100)
  
  base_plot = ggplot(as.data.frame(pc)) +
    geom_point(aes(x = PC1, y = PC2, colour = NZ), alpha = 0.7) +
    scale_colour_manual(
      values = c("#619CFF", "#00BA38", "#F8766D"),
      labels = c("Extant (alien)", "Extant (native)", "Extinct")
    ) +
    theme(
      panel.background = element_rect(fill = "white"),
      axis.line = element_line(colour = "black", linewidth = 0.4),
      text = element_text(family = "Leelawadee UI Semilight")
    ) +
    coord_cartesian(ylim = c(-4, 2), xlim = c(-8, 6)) +
    labs(colour = "")
  
  ##TPD
  kd_ext <-
    ks::kde(pc[pc$NZ != c("ExtantAlien"), c(3:4)], compute.cont = TRUE)
  contour_95_ext <-
    with(kd_ext,
         contourLines(
           x = eval.points[[1]],
           y = eval.points[[2]],
           z = estimate,
           levels = cont["5%"]
         )[[1]])
  
  contour_95_ext <- data.frame(contour_95_ext)
  
  kd_al <-
    ks::kde(pc[pc$NZ != c("Extinct"), c(3:4)], compute.cont = TRUE)
  contour_95_al <-
    with(kd_al,
         contourLines(
           x = eval.points[[1]],
           y = eval.points[[2]],
           z = estimate,
           levels = cont["5%"]
         )[[1]])
  
  contour_95_al <- data.frame(contour_95_al)
  
  tpd_plot = ggplot(data = pc, aes(PC1, PC2)) +
    geom_point(aes(x = PC1, y = PC2, colour = NZ), show.legend = F) +
    scale_colour_manual(
      values = c("#619CFF", "#00BA38", "#F8766D"),
      labels = c("Extant (alien)", "Extant (native)", "Extinct")
    ) +
    annotate(
      "rect",
      xmin = -14,
      xmax = 8,
      ymin = -5,
      ymax = 14,
      fill = "white",
      alpha = 0.6
    ) +
    new_scale_colour() +
    geom_path(aes(x, y, col = "Extant native and extinct species"), data = contour_95_ext) +
    geom_path(aes(x, y, col = "Extant native and extant alien species"), data = contour_95_al) +
    theme(
      panel.background = element_rect(fill = "white"),
      axis.line = element_line(colour = "black", linewidth = 0.4),
      #legend.position="none",
      text = element_text(family = "Leelawadee UI Semilight")
    ) +
    coord_cartesian(ylim = c(-4, 2), xlim = c(-8, 6)) +
    labs(colour = "TPD richness") +
    scale_colour_manual(
      values = c("#619CFF", "#F8766D"),
      labels = c("with extinct species" ,
                 "with extant alien species")
    )
  
  hull_ex <- pc %>%
    subset(NZ != "ExtantAlien") %>%
    slice(chull(PC1, PC2))
  
  hull_al <- pc %>%
    subset(NZ != "Extinct") %>%
    slice(chull(PC1, PC2))
  
  hull_plot = ggplot(data = pc, aes(PC1, PC2)) +
    geom_point(aes(x = PC1, y = PC2, colour = NZ), show.legend = F) +
    scale_colour_manual(
      values = c("#619CFF", "#00BA38", "#F8766D"),
      labels = c("Extant (alien)", "Extant (native)", "Extinct")
    ) +
    new_scale_color() +
    annotate(
      "rect",
      xmin = -14,
      xmax = 8,
      ymin = -5,
      ymax = 14,
      fill = "white",
      alpha = 0.6
    ) +
    geom_polygon(data = hull_ex, aes(col = "with extinct species"), fill = "NA") +
    geom_polygon(data = hull_al,
                 aes(col = "with extant alien species"),
                 fill = "NA") +
    theme(
      panel.background = element_rect(fill = "white"),
      axis.line = element_line(colour = "black", linewidth = 0.4),
      text = element_text(family = "Leelawadee UI Semilight")
    ) +
    coord_cartesian(ylim = c(-4, 2), xlim = c(-8, 6)) +
    labs(colour = "Convex hull") +
    scale_colour_manual(
      values = c("#619CFF", "#F8766D"),
      labels = c("with extinct species" ,
                 "with extant alien species")
    )
  
  return(list(base_plot, tpd_plot, hull_plot))
}

NZ=plot_ex("NZ")
NZ_nomiss=plot_ex("NZ",T)


NewZealand=plot_ex("New.Zealand")
NewZealand_nomiss=plot_ex("New.Zealand", T)

grid.arrange(NewZealand[[2]], NewZealand_nomiss[[2]])

grid.arrange(NewZealand[[2]], NewZealand[[3]])

NZ=arrangeGrob(NewZealand[[2]], NewZealand[[3]])

ggsave(NZ,file="NewZealand_ric.png")
ggsave(NewZealand[[1]], file="NewZealand.png")
